#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "datafile.h"
#include "error.h"
#include "getref.h"
#include "global.h"

/* TASK -- Driver for the getref task
 *
 * i: argc      number of task arguments
 * i: argv      array of pointers to task arguments
 *
 * History:
 * 09/20/04  52054  MSwam   use topdir to fill GETREF_*_HTML filenames
 */
 
void task (int argc, char ** argv)
{
    int		iarg;
    table	*tab;
    char	template[SZ_FNAME+1], mytop[SZ_FNAME+1];
    char	root[SZ_PARAM+1];

    /* Read the values of the task parameter root from the command line */

    root[0] = EOS;
    for (iarg = 1; iarg < argc; iarg ++) {
	if (iarg == 1) {
	    safecopy (root, "root=", SZ_PARAM);
	} else {
	    safecat (root, ",", SZ_PARAM);
	}

	safecat (root, argv[iarg], SZ_PARAM);
    }

    if (root[0] != EOS)
	put_option (root);

    /* Read the cgi form input */

    form_input ();

    /* Install the cgi error handler if input is from a cgi form 
     * and set default values of parameters
     */

    if (yorn (get_option ("HTML")) == YES) {
	cdbs_errhandler = cgi_error;
	def_option ("text=no");
    } else {
        def_option ("text=yes");
    }

    def_option ("retry=no,fits=no,root=,reffile=");

    /* Perform appropriate query and store results in table */

    safecopy(template, topdir(mytop), SZ_FNAME);
    switch (which_qry ()) {
    case NOREF:
	tab = NULL;
	safecopy(template, GETREF_NO_HTML, SZ_FNAME);
	break;
    case ALLREF:
	tab = getref_all ();
	safecopy(template, GETREF_ALL_HTML, SZ_FNAME);
	break;
    case ONEREF:
	tab = getref_one ();
	safecopy(template, GETREF_ONE_HTML, SZ_FNAME);
	break;
    }

    /* Write results from table using appropriate format */

    if (yorn (get_option ("text")) == NO) {
	output_html (template, tab);
    } else {
	output_asc (tab);
    }

    if (tab != NULL)
	free_table (tab);
}
